# Converters

This directory contains file converters that are not shipped with PolyA itself
because they are either outdated or of extremely limited utility for the broader
user base.

See the `polyA.converters` package for more common converters.